pub struct VerifiedSourceState {
pub provider_user_id: Option<String>,
pub email: Option<String>,
pub account_label: Option<String>,
pub plan_name: Option<String>,
pub authenticated_at: Option<DateTime<Utc>>,
pub verified_at: Option<DateTime<Utc>>,
pub subscription: Option<VerifiedSubscriptionState>,
}Fields
provider_user_id: Option<String>email: Option<String>account_label: Option<String>plan_name: Option<String>authenticated_at: Option<DateTime<Utc>>verified_at: Option<DateTime<Utc>>subscription: Option<VerifiedSubscriptionState>Trait Implementations
Sourceimpl Clone for VerifiedSourceState
impl Clone for VerifiedSourceState
Sourcefn clone(&self) -> VerifiedSourceState
fn clone(&self) -> VerifiedSourceState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifiedSourceState
impl Debug for VerifiedSourceState
Sourceimpl<'de> Deserialize<'de> for VerifiedSourceState
impl<'de> Deserialize<'de> for VerifiedSourceState
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VerifiedSourceState, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VerifiedSourceState, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerifiedSourceState
impl JsonSchema for VerifiedSourceState
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerifiedSourceState
impl PartialEq for VerifiedSourceState
Sourcefn eq(&self, other: &VerifiedSourceState) -> bool
fn eq(&self, other: &VerifiedSourceState) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VerifiedSourceState
impl Serialize for VerifiedSourceState
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for VerifiedSourceState