pub struct VerifiedSubscriptionState {
pub plan_name: String,
pub price: i64,
pub currency: String,
pub billing_period: BillingPeriod,
pub paid_at: Option<DateTime<Utc>>,
pub started_at: DateTime<Utc>,
pub ended_at: Option<DateTime<Utc>>,
pub current_period_ends_at: Option<DateTime<Utc>>,
pub status: SubscriptionStatus,
pub verified_at: Option<DateTime<Utc>>,
}Fields
plan_name: Stringprice: i64currency: Stringbilling_period: BillingPeriodpaid_at: Option<DateTime<Utc>>started_at: DateTime<Utc>ended_at: Option<DateTime<Utc>>current_period_ends_at: Option<DateTime<Utc>>status: SubscriptionStatusverified_at: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for VerifiedSubscriptionState
impl Clone for VerifiedSubscriptionState
Sourcefn clone(&self) -> VerifiedSubscriptionState
fn clone(&self) -> VerifiedSubscriptionState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifiedSubscriptionState
impl Debug for VerifiedSubscriptionState
Sourceimpl<'de> Deserialize<'de> for VerifiedSubscriptionState
impl<'de> Deserialize<'de> for VerifiedSubscriptionState
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VerifiedSubscriptionState, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VerifiedSubscriptionState, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerifiedSubscriptionState
impl JsonSchema for VerifiedSubscriptionState
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerifiedSubscriptionState
impl PartialEq for VerifiedSubscriptionState
Sourcefn eq(&self, other: &VerifiedSubscriptionState) -> bool
fn eq(&self, other: &VerifiedSubscriptionState) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VerifiedSubscriptionState
impl Serialize for VerifiedSubscriptionState
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for VerifiedSubscriptionState